@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 #coding:utf-8
-# Author:  mozman --<mozman@gmx.at>
 # Purpose: test wrapcache
 # Created: 29.01.2011
 # Copyright (C) 2011, Manfred Moitzi
-# License: GPLv3
+# License: MIT license
+from __future__ import unicode_literals, print_function, division
+__author__ = "mozman <mozman@gmx.at>"
 
 import unittest
 
@@ -29,5 +30,12 @@ class TestWrapCache(unittest.TestCase):
         copy2 = wrapcache.wrap(original.xmlnode)
         self.assertFalse(original is copy2)
 
+    def test_remove(self):
+        original = GenericWrapper()
+        wrapcache.add(original)
+        wrapcache.remove(original)
+        copy = wrapcache.wrap(original.xmlnode)
+        self.assertTrue(original is not copy)
+
 if __name__=='__main__':
-    unittest.main()
\ No newline at end of file
+    unittest.main()
